@@ -5,22 +5,25 @@
 from .work_pool import WorkPool
 from .work_pool_task import WorkPoolTask
 from .work_pool_task import WorkPoolTaskCallbacksContainer, WorkPoolTaskErrorCallback
-
-from retrying import retry
-from oci_cli import retry_utils
+from oci._vendor.urllib3.exceptions import (
+    ReadTimeoutError,
+    ProtocolError
+)
 
 import heapq
 import oci
+import os
 import six
 import threading
+import random
+import time
 
 
 MEBIBYTE = 1024 * 1024
 OBJECT_GET_CHUNK_SIZE = MEBIBYTE
+DEFAULT_RETRY_COUNT = 5
 
 
-@retry(stop_max_attempt_number=3, wait_exponential_multiplier=1000, wait_exponential_max=10000, wait_jitter_max=2000,
-       retry_on_exception=retry_utils.retry_on_timeouts_connection_internal_server_and_throttles)
 def _make_retrying_get_call(object_storage_client, **kwargs):
     return object_storage_client.get_object(
         kwargs['namespace'],
@@ -36,6 +39,36 @@ def _make_retrying_get_call(object_storage_client, **kwargs):
     )
 
 
+# Retry the given function with exponential backoff until either retry count is zero or exception is not retryable
+def _retry_with_backoff(fn, *fn_args, **kwargs):
+    retries = DEFAULT_RETRY_COUNT
+    backoff_multiplier_in_secs = 1
+    if 'retries' in kwargs:
+        retries = kwargs["retries"]
+    if 'backoff_multiplier_in_secs' in kwargs:
+        backoff_multiplier_in_secs = kwargs["backoff_multiplier_in_secs"]
+    retry_count = 0
+
+    while True:
+        try:
+            return fn(*fn_args)
+        except Exception as e:
+            # Raise if retries are exhausted or exception is not retryable
+            if (retry_count == retries) or (not _is_retryable(e)):
+                raise
+            sleep = (backoff_multiplier_in_secs * 2 ** retry_count + random.uniform(0, 1))
+            time.sleep(sleep)
+            retry_count += 1
+
+
+# Check if the exception is retryable, currently this is either ConnectionError or ReadTimeoutError
+# or ProtocolError (which can be due either ConnectionResetError or ReadIncompleteError)
+def _is_retryable(exception):
+    if isinstance(exception, (ConnectionError, ReadTimeoutError, ProtocolError)):
+        return True
+    return False
+
+
 # A task which can retrieve an object from Object Storage and write it to a file
 class GetObjectTask(WorkPoolTask):
     def __init__(self, object_storage_client, callbacks_container, **kwargs):
@@ -51,8 +84,8 @@ class GetObjectTask(WorkPoolTask):
                 for chunk in get_object_response.data.raw.stream(OBJECT_GET_CHUNK_SIZE, decode_content=False):
                     file.write(chunk)
         except IOError as e:
-            # IsADirectoryError
-            if e.errno == 21:
+            # IsADirectoryError, PermissionError
+            if e.errno == 21 or (e.errno == 13 and os.path.isdir(self.kwargs['full_file_path'])):
                 pass
             else:
                 raise
@@ -214,8 +247,6 @@ class GetObjectMultipartTask(WorkPoolTask):
 
         raise RuntimeError('Error downloading parts: {}'.format('\n'.join(errors)))
 
-    @retry(stop_max_attempt_number=3, wait_exponential_multiplier=1000, wait_exponential_max=10000, wait_jitter_max=2000,
-           retry_on_exception=retry_utils.retry_on_timeouts_connection_internal_server_and_throttles)
     def _make_retrying_head_object_call(self):
         try:
             return self.object_storage_client.head_object(
@@ -248,7 +279,7 @@ class GetObjectRangeTask(WorkPoolTask):
         self.io_writer_pool = io_writer_pool
         self.pending_writes = pending_writes
         self.add_pending_write_lock = add_pending_write_lock
-
+        self.retry_count = 0 if isinstance(self.object_storage_client.retry_strategy, oci.retry.NoneRetryStrategy) else DEFAULT_RETRY_COUNT
         self.destination_file_handle = destination_file_handle
         self.downloaded_data = six.BytesIO()
 
@@ -265,16 +296,9 @@ class GetObjectRangeTask(WorkPoolTask):
             self.part_completed_callback = None
 
     def do_work_hook(self):
-        get_object_response = _make_retrying_get_call(self.object_storage_client, **self.kwargs)
-        total_size = 0
-        for chunk in get_object_response.data.raw.stream(OBJECT_GET_CHUNK_SIZE, decode_content=False):
-            self.downloaded_data.write(chunk)
-            total_size += len(chunk)
-            if self.chunk_written_callback:
-                self.chunk_written_callback(len(chunk) / 2)
-
-        if self.part_completed_callback:
-            self.part_completed_callback(total_size)
+        # Get object request -> stream data with retries (connection breaks during data streaming will raise urllib
+        # exceptions which are being caught in _retry_with_backoff)
+        self.downloaded_data = _retry_with_backoff(self._get_object, retries=self.retry_count)
 
         # PendingWrites uses heapq, which is not thread safe, so we need to lock it
         with self.add_pending_write_lock:
@@ -290,6 +314,19 @@ class GetObjectRangeTask(WorkPoolTask):
                 )
             )
 
+    def _get_object(self):
+        downloaded_data = six.BytesIO()
+        get_object_response = _make_retrying_get_call(self.object_storage_client, **self.kwargs)
+        total_size = 0
+        for chunk in get_object_response.data.raw.stream(None, decode_content=False):
+            downloaded_data.write(chunk)
+            total_size += len(chunk)
+            if self.chunk_written_callback:
+                self.chunk_written_callback(len(chunk))
+        if self.part_completed_callback:
+            self.part_completed_callback(total_size)
+        return downloaded_data
+
 
 class GetObjectRangeIOWriterTask(WorkPoolTask):
     READ_WRITE_CHUNK_SIZE = 10 * MEBIBYTE
