@@ -44,7 +44,7 @@ def create_base64encoded_tf_state(tf_state):
 @cli_util.option('--working-directory', help=""" The path of the directory from which to run terraform. If not specified the root will be used.""")
 @cli_util.option('--wait-for-state', type=custom_types.CliCaseInsensitiveChoice(["CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "NOT_CHECKED", "IN_SYNC", "DRIFTED"]), multiple=True, help="""This operation asynchronously creates, modifies or deletes a resource and uses a work request to track the progress of the operation. Specify this option to perform the action and then wait until the work request reaches a certain state. Multiple states can be specified, returning on the first state. For example, --wait-for-state SUCCEEDED --wait-for-state FAILED would return on whichever lifecycle state is reached first. If timeout is reached, a return code of 2 is returned. For any other error, a return code of 1 is returned.""")
 @click.pass_context
-@json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'variables': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}}, output_type={'module': 'resource_manager', 'class': 'Stack'})
+@json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'custom-terraform-provider': {'module': 'resource_manager', 'class': 'CustomTerraformProvider'}, 'variables': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}}, output_type={'module': 'resource_manager', 'class': 'Stack'})
 @cli_util.wrap_exceptions
 def create_stack_extended(ctx, from_json, wait_for_state, max_wait_seconds, wait_interval_seconds, compartment_id, config_source, display_name, description, variables, terraform_version, freeform_tags, defined_tags, working_directory, **kwargs):
 
@@ -139,7 +139,7 @@ def create_stack_extended(ctx, from_json, wait_for_state, max_wait_seconds, wait
 @cli_util.option('--config-source', help="""A Terraform configuration .zip file.""")
 @cli_util.option('--working-directory', help=""" The path of the directory from which to run terraform. If not specified the root will be used.""")
 @click.pass_context
-@json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'variables': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}}, output_type={'module': 'reseouce_manager', 'class': 'Stack'})
+@json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'custom-terraform-provider': {'module': 'resource_manager', 'class': 'CustomTerraformProvider'}, 'variables': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}}, output_type={'module': 'reseouce_manager', 'class': 'Stack'})
 @cli_util.wrap_exceptions
 def update_stack_extended(ctx, config_source, working_directory, **kwargs):
 
@@ -180,13 +180,19 @@ resourcemanager_cli.job_group.commands.pop(resourcemanager_cli.create_job_create
 
 
 # params_to_exclude will remove unwanted params
-@cli_util.copy_params_from_generated_command(resourcemanager_cli.create_job_create_plan_job_operation_details, params_to_exclude=['operation', 'apply_job_plan_resolution'])
+@cli_util.copy_params_from_generated_command(resourcemanager_cli.create_job_create_plan_job_operation_details, params_to_exclude=['operation', 'apply_job_plan_resolution', 'job_operation_details_terraform_advanced_options'])
 # Create a new command with name 'create-plan-job'
 @resourcemanager_cli.job_group.command(name='create-plan-job', help=resourcemanager_cli.create_job_create_plan_job_operation_details.help)
+# New/Renamed options
+@cli_util.option('--terraform-advanced-options', type=custom_types.CLI_COMPLEX_TYPE, help=u"""Specifies advanced options for Terraform commands. These options are not necessary for normal usage of Terraform.\n""" + custom_types.cli_complex_type.COMPLEX_TYPE_HELP)
 @click.pass_context
 @json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}}, output_type={'module': 'resource_manager', 'class': 'Job'})
 @cli_util.wrap_exceptions
 def create_plan_job(ctx, **kwargs):
+    # Extract the renamed options and construct original options.
+    if 'terraform_advanced_options' in kwargs:
+        kwargs['job_operation_details_terraform_advanced_options'] = kwargs['terraform_advanced_options']
+        del kwargs['terraform_advanced_options']
     # invoke generated command.
     ctx.invoke(resourcemanager_cli.create_job_create_plan_job_operation_details, **kwargs)
 
@@ -197,12 +203,13 @@ resourcemanager_cli.job_group.commands.pop(resourcemanager_cli.create_job_create
 
 
 # params_to_exclude will remove unwanted params
-@cli_util.copy_params_from_generated_command(resourcemanager_cli.create_job_create_apply_job_operation_details, params_to_exclude=['job_operation_details_execution_plan_strategy', 'job_operation_details_execution_plan_job_id', 'operation', 'apply_job_plan_resolution'])
+@cli_util.copy_params_from_generated_command(resourcemanager_cli.create_job_create_apply_job_operation_details, params_to_exclude=['job_operation_details_execution_plan_strategy', 'job_operation_details_execution_plan_job_id', 'operation', 'apply_job_plan_resolution', 'job_operation_details_terraform_advanced_options'])
 # Create a new command with name 'create-apply-job'
 @resourcemanager_cli.job_group.command(name='create-apply-job', help=resourcemanager_cli.create_job_create_apply_job_operation_details.help)
 # New/Renamed options
 @cli_util.option('--execution-plan-job-id', help=u"""Specifies the source of the execution plan to apply. Use `AUTO_APPROVED` to run the job without an execution plan.""")
 @cli_util.option('--execution-plan-strategy', required=True, help=u"""The OCID of a plan job, for use when specifying `FROM_PLAN_JOB_ID` as the `executionPlanStrategy`.""")
+@cli_util.option('--terraform-advanced-options', type=custom_types.CLI_COMPLEX_TYPE, help=u"""Specifies advanced options for Terraform commands. These options are not necessary for normal usage of Terraform.\n""" + custom_types.cli_complex_type.COMPLEX_TYPE_HELP)
 @click.pass_context
 @json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}}, output_type={'module': 'resource_manager', 'class': 'Job'})
 @cli_util.wrap_exceptions
@@ -214,6 +221,9 @@ def create_apply_job(ctx, **kwargs):
     if 'execution_plan_job_id' in kwargs:
         kwargs['job_operation_details_execution_plan_job_id'] = kwargs['execution_plan_job_id']
         del kwargs['execution_plan_job_id']
+    if 'terraform_advanced_options' in kwargs:
+        kwargs['job_operation_details_terraform_advanced_options'] = kwargs['terraform_advanced_options']
+        del kwargs['terraform_advanced_options']
 
     # invoke generated command.
     ctx.invoke(resourcemanager_cli.create_job_create_apply_job_operation_details, **kwargs)
@@ -225,11 +235,12 @@ resourcemanager_cli.job_group.commands.pop(resourcemanager_cli.create_job_create
 
 
 # params_to_exclude will remove unwanted params
-@cli_util.copy_params_from_generated_command(resourcemanager_cli.create_job_create_destroy_job_operation_details, params_to_exclude=['job_operation_details_execution_plan_strategy', 'operation', 'apply_job_plan_resolution'])
+@cli_util.copy_params_from_generated_command(resourcemanager_cli.create_job_create_destroy_job_operation_details, params_to_exclude=['job_operation_details_execution_plan_strategy', 'operation', 'apply_job_plan_resolution', 'job_operation_details_terraform_advanced_options'])
 # Create a new command with name 'create-destroy-job'
 @resourcemanager_cli.job_group.command(name='create-destroy-job', help=resourcemanager_cli.create_job_create_destroy_job_operation_details.help)
 # New/Renamed options
 @cli_util.option('--execution-plan-strategy', required=True, help=u"""Specifies the source of the execution plan to apply. Currently, only `AUTO_APPROVED` is allowed, which indicates that the job will be run without an execution plan.""")
+@cli_util.option('--terraform-advanced-options', type=custom_types.CLI_COMPLEX_TYPE, help=u"""Specifies advanced options for Terraform commands. These options are not necessary for normal usage of Terraform.\n""" + custom_types.cli_complex_type.COMPLEX_TYPE_HELP)
 @click.pass_context
 @json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}}, output_type={'module': 'resource_manager', 'class': 'Job'})
 @cli_util.wrap_exceptions
@@ -238,6 +249,9 @@ def create_destroy_job(ctx, **kwargs):
     if 'execution_plan_strategy' in kwargs:
         kwargs['job_operation_details_execution_plan_strategy'] = kwargs['execution_plan_strategy']
         del kwargs['execution_plan_strategy']
+    if 'terraform_advanced_options' in kwargs:
+        kwargs['job_operation_details_terraform_advanced_options'] = kwargs['terraform_advanced_options']
+        del kwargs['terraform_advanced_options']
 
     # invoke generated command.
     ctx.invoke(resourcemanager_cli.create_job_create_destroy_job_operation_details, **kwargs)
@@ -255,7 +269,7 @@ resourcemanager_cli.job_group.commands.pop(resourcemanager_cli.create_job_create
 # New/Renamed options
 @cli_util.option('--tf-state-file', required=True, help=u"""Job details that are specific to import Terraform state operations.""")
 @click.pass_context
-@json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}}, output_type={'module': 'resource_manager', 'class': 'Job'})
+@json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'apply-job-plan-resolution': {'module': 'resource_manager', 'class': 'ApplyJobPlanResolution'}, 'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}}, output_type={'module': 'resource_manager', 'class': 'Job'})
 @cli_util.wrap_exceptions
 def create_import_tf_state_job(ctx, **kwargs):
     # Extract the renamed options and construct original options.
@@ -688,3 +702,138 @@ def get_source_stack_tf_config_base64encoded_zip(stack_id, stack_tf_config_respo
 
 
 resourcemanager_cli.stack_group.add_command(copy_stack)
+
+# oci resource-manager job get-job-detailed-log-content -> oci resource-manager job get-detailed-log-content
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.job_group, resourcemanager_cli.get_job_detailed_log_content, "get-detailed-log-content")
+
+
+# oci resource-manager private-endpoint-summary list-private-endpoints -> oci resource-manager private-endpoint-summary list
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.private_endpoint_summary_group, resourcemanager_cli.list_private_endpoints, "list")
+
+
+# oci resource-manager reachable-ip get -> oci resource-manager reachable-ip get-reachable-ip
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.reachable_ip_group, resourcemanager_cli.get_reachable_ip, "get-reachable-ip")
+
+
+# Remove reachable-ip from oci resource-manager
+resourcemanager_cli.resource_manager_root_group.commands.pop(resourcemanager_cli.reachable_ip_group.name)
+
+
+# Remove private-endpoint-summary from oci resource-manager
+resourcemanager_cli.resource_manager_root_group.commands.pop(resourcemanager_cli.private_endpoint_summary_group.name)
+
+
+# oci resource-manager private-endpoint-summary list-private-endpoints -> oci resource-manager private-endpoint
+resourcemanager_cli.private_endpoint_summary_group.commands.pop(resourcemanager_cli.list_private_endpoints.name)
+resourcemanager_cli.private_endpoint_group.add_command(resourcemanager_cli.list_private_endpoints)
+
+
+# oci resource-manager reachable-ip get -> oci resource-manager private-endpoint
+resourcemanager_cli.reachable_ip_group.commands.pop(resourcemanager_cli.get_reachable_ip.name)
+resourcemanager_cli.private_endpoint_group.add_command(resourcemanager_cli.get_reachable_ip)
+
+
+# oci resource-manager job create-job-create-apply-rollback-job-operation-details -> oci resource-manager job create-apply-rollback-job
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.job_group, resourcemanager_cli.create_job_create_apply_rollback_job_operation_details, "create-apply-rollback-job")
+
+
+# oci resource-manager job create-job-create-plan-rollback-job-operation-details -> oci resource-manager job create-plan-rollback-job
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.job_group, resourcemanager_cli.create_job_create_plan_rollback_job_operation_details, "create-plan-rollback-job")
+
+
+@cli_util.copy_params_from_generated_command(resourcemanager_cli.create_job_create_apply_rollback_job_operation_details, params_to_exclude=['job_operation_details_execution_plan_rollback_strategy', 'job_operation_details_execution_plan_rollback_job_id', 'job_operation_details_target_rollback_job_id', 'job_operation_details_terraform_advanced_options', 'job_operation_details_is_provider_upgrade_required', 'apply_job_plan_resolution'])
+@resourcemanager_cli.job_group.command(name=resourcemanager_cli.create_job_create_apply_rollback_job_operation_details.name, help=resourcemanager_cli.create_job_create_apply_rollback_job_operation_details.help)
+@cli_util.option('--execution-plan-rollback-strategy', required=True, help=u"""Specifies the source of the execution plan for rollback to apply. Use `AUTO_APPROVED` to run the job without an execution plan for rollback job. [required]""")
+@cli_util.option('--execution-plan-rollback-job-id', help=u"""The [OCID] of a plan rollback job, for use when specifying `"FROM_PLAN_ROLLBACK_JOB_ID"` as the `executionPlanRollbackStrategy`.""")
+@cli_util.option('--target-rollback-job-id', help=u"""The [OCID] of a successful apply job, for use when specifying `"AUTO_APPROVED"` as the `executionPlanRollbackStrategy`.""")
+@cli_util.option('--terraform-advanced-options', type=custom_types.CLI_COMPLEX_TYPE, help=u"""This is a complex type whose value must be valid JSON. The value can be provided as a string on the command line or passed in as a file using
+the file://path/to/file syntax.
+
+The --generate-param-json-input option can be used to generate an example of the JSON which must be provided. We recommend storing this example
+in a file, modifying it as needed and then passing it back in via the file:// syntax.""")
+@click.pass_context
+@json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'apply-job-plan-resolution': {'module': 'resource_manager', 'class': 'ApplyJobPlanResolution'}, 'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}, 'terraform-advanced-options': {'module': 'resource_manager', 'class': 'TerraformAdvancedOptions'}}, output_type={'module': 'resource_manager', 'class': 'Job'})
+@cli_util.wrap_exceptions
+def create_job_create_apply_rollback_job_operation_details_extended(ctx, **kwargs):
+
+    if 'execution_plan_rollback_strategy' in kwargs:
+        kwargs['job_operation_details_execution_plan_rollback_strategy'] = kwargs['execution_plan_rollback_strategy']
+        kwargs.pop('execution_plan_rollback_strategy')
+
+    if 'execution_plan_rollback_job_id' in kwargs:
+        kwargs['job_operation_details_execution_plan_rollback_job_id'] = kwargs['execution_plan_rollback_job_id']
+        kwargs.pop('execution_plan_rollback_job_id')
+
+    if 'target_rollback_job_id' in kwargs:
+        kwargs['job_operation_details_target_rollback_job_id'] = kwargs['target_rollback_job_id']
+        kwargs.pop('target_rollback_job_id')
+
+    if 'terraform_advanced_options' in kwargs:
+        kwargs['job_operation_details_terraform_advanced_options'] = kwargs['terraform_advanced_options']
+        kwargs.pop('terraform_advanced_options')
+
+    ctx.invoke(resourcemanager_cli.create_job_create_apply_rollback_job_operation_details, **kwargs)
+
+
+@cli_util.copy_params_from_generated_command(resourcemanager_cli.create_job_create_plan_rollback_job_operation_details, params_to_exclude=['job_operation_details_target_rollback_job_id', 'job_operation_details_terraform_advanced_options', 'job_operation_details_is_provider_upgrade_required', 'apply_job_plan_resolution'])
+@resourcemanager_cli.job_group.command(name=resourcemanager_cli.create_job_create_plan_rollback_job_operation_details.name, help=resourcemanager_cli.create_job_create_plan_rollback_job_operation_details.help)
+@cli_util.option('--target-rollback-job-id', required=True, help=u"""The [OCID] of a successful apply job to use for the plan rollback job. [required]""")
+@cli_util.option('--terraform-advanced-options', type=custom_types.CLI_COMPLEX_TYPE, help=u"""This is a complex type whose value must be valid JSON. The value can be provided as a string on the command line or passed in as a file using
+the file://path/to/file syntax.
+
+The --generate-param-json-input option can be used to generate an example of the JSON which must be provided. We recommend storing this example
+in a file, modifying it as needed and then passing it back in via the file:// syntax.""")
+@click.pass_context
+@json_skeleton_utils.json_skeleton_generation_handler(input_params_to_complex_types={'custom-terraform-provider': {'module': 'resource_manager', 'class': 'CustomTerraformProvider'}, 'variables': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'freeform-tags': {'module': 'resource_manager', 'class': 'dict(str, string)'}, 'defined-tags': {'module': 'resource_manager', 'class': 'dict(str, dict(str, object))'}, 'terraform-advanced-options': {'module': 'resource_manager', 'class': 'TerraformAdvancedOptions'}}, output_type={'module': 'resource_manager', 'class': 'Job'})
+@cli_util.wrap_exceptions
+def create_job_create_plan_rollback_job_operation_details_extended(ctx, **kwargs):
+
+    if 'target_rollback_job_id' in kwargs:
+        kwargs['job_operation_details_target_rollback_job_id'] = kwargs['target_rollback_job_id']
+        kwargs.pop('target_rollback_job_id')
+
+    if 'terraform_advanced_options' in kwargs:
+        kwargs['job_operation_details_terraform_advanced_options'] = kwargs['terraform_advanced_options']
+        kwargs.pop('terraform_advanced_options')
+
+    if 'branch_name' in kwargs:
+        kwargs['config_source_branch_name'] = kwargs['branch_name']
+        kwargs.pop('branch_name')
+
+    if 'working_directory' in kwargs:
+        kwargs['config_source_working_directory'] = kwargs['working_directory']
+        kwargs.pop('working_directory')
+
+    ctx.invoke(resourcemanager_cli.update_stack_update_dev_ops_config_source_details, **kwargs)
+
+
+# oci resource-manager configuration-source-provider create-configuration-source-provider-create-bitbucket-cloud-username-app-password-configuration-source-provider-details -> oci resource-manager configuration-source-provider create-bitbucket-cloud-username-app-password-provider
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.configuration_source_provider_group, resourcemanager_cli.create_configuration_source_provider_create_bitbucket_cloud_username_app_password_configuration_source_provider_details, "create-bitbucket-cloud-username-app-password-provider")
+
+
+# oci resource-manager configuration-source-provider create-configuration-source-provider-create-bitbucket-server-access-token-configuration-source-provider-details -> oci resource-manager configuration-source-provider create-bitbucket-server-access-token-provider
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.configuration_source_provider_group, resourcemanager_cli.create_configuration_source_provider_create_bitbucket_server_access_token_configuration_source_provider_details, "create-bitbucket-server-access-token-provider")
+
+
+# oci resource-manager configuration-source-provider update-configuration-source-provider-update-bitbucket-cloud-username-app-password-configuration-source-provider-details -> oci resource-manager configuration-source-provider update-bitbucket-cloud-username-app-password-provider
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.configuration_source_provider_group, resourcemanager_cli.update_configuration_source_provider_update_bitbucket_cloud_username_app_password_configuration_source_provider_details, "update-bitbucket-cloud-username-app-password-provider")
+
+
+# oci resource-manager configuration-source-provider update-configuration-source-provider-update-bitbucket-server-access-token-configuration-source-provider-details -> oci resource-manager configuration-source-provider update-bitbucket-server-access-token-provider
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.configuration_source_provider_group, resourcemanager_cli.update_configuration_source_provider_update_bitbucket_server_access_token_configuration_source_provider_details, "update-bitbucket-server-access-token-provider")
+
+
+# oci resource-manager stack create-stack-create-bitbucket-cloud-config-source-details -> oci resource-manager stack create-from-bitbucket-cloud
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.stack_group, resourcemanager_cli.create_stack_create_bitbucket_cloud_config_source_details, "create-from-bitbucket-cloud")
+
+
+# oci resource-manager stack create-stack-create-bitbucket-server-config-source-details -> oci resource-manager stack create-from-bitbucket-server
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.stack_group, resourcemanager_cli.create_stack_create_bitbucket_server_config_source_details, "create-from-bitbucket-server")
+
+
+# oci resource-manager stack update-stack-update-bitbucket-cloud-config-source-details -> oci resource-manager stack update-from-bitbucket-cloud
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.stack_group, resourcemanager_cli.update_stack_update_bitbucket_cloud_config_source_details, "update-from-bitbucket-cloud")
+
+
+# oci resource-manager stack update-stack-update-bitbucket-server-config-source-details -> oci resource-manager stack code
+cli_util.rename_command(resourcemanager_cli, resourcemanager_cli.stack_group, resourcemanager_cli.update_stack_update_bitbucket_server_config_source_details, "code")
