@@ -7,3 +7,6 @@ ROVER_CLUSTER_STANDALONE_TYPE = "STANDALONE"
 ROVER_UPGRADE_BUNDLE_UPLOAD_BUCKET = "rover-system-upgrade-staging"
 ROVER_DIAGNOSTIC_BUNDLE_API_BASE_PATH = "/20220901/bundles"
 DEFAULT_ROVER_DEVICE_ENDPOINT = "https://vcluster-1-red-1:23060"
+TERMINAL_STATES = ["IMPORTED", "FAILURE", "DECRYPTION_FAILURE", "ENCRYPTION_KEY_IMPORT_FAILURE"]
+NON_TERMINAL_STATES = ["INITIALIZING", "VALIDATING_VERSION", "DECRYPTED", "DECRYPTING", "VERIFYING_SIGNATURE",
+                       "FINALIZING"]
