@@ -24,55 +24,55 @@ def host_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.host_scan_group.command_name', 'scan'), cls=CommandGroupWithAlias, help="""A host scan command group""")
+@click.command(cli_util.override('vulnerability_scanning.host_group.command_name', 'scan'), cls=CommandGroupWithAlias, help="""A host scan command group""")
 @cli_util.help_option_group
 def host_scan_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.host_scan_result_group.command_name', 'result'), cls=CommandGroupWithAlias, help="""A host scan result command group""")
+@click.command(cli_util.override('vulnerability_scanning.host_group.command_name', 'result'), cls=CommandGroupWithAlias, help="""A host scan result command group""")
 @cli_util.help_option_group
 def host_scan_result_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.host_scan_result_port_group.command_name', 'port'), cls=CommandGroupWithAlias, help="""A host scan port-result command group""")
+@click.command(cli_util.override('vulnerability_scanning.host_group.command_name', 'port'), cls=CommandGroupWithAlias, help="""A host scan port-result command group""")
 @cli_util.help_option_group
 def host_scan_result_port_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.host_scan_result_agent_group.command_name', 'agent'), cls=CommandGroupWithAlias, help="""A host scan agent-result command group""")
+@click.command(cli_util.override('vulnerability_scanning.host_group.command_name', 'agent'), cls=CommandGroupWithAlias, help="""A host scan agent-result command group""")
 @cli_util.help_option_group
 def host_scan_result_agent_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.host_scan_result_cis_benchmark_group.command_name', 'cis-benchmark'), cls=CommandGroupWithAlias, help="""A host scan cis-benchmark-result command group""")
+@click.command(cli_util.override('vulnerability_scanning.host_group.command_name', 'cis-benchmark'), cls=CommandGroupWithAlias, help="""A host scan cis-benchmark-result command group""")
 @cli_util.help_option_group
 def host_scan_result_cis_benchmark_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.host_scan_result_endpoint_protection_group.command_name', 'endpoint-protection'), cls=CommandGroupWithAlias, help="""A host scan endpoint-protection-result command group""")
+@click.command(cli_util.override('vulnerability_scanning.host_group.command_name', 'endpoint-protection'), cls=CommandGroupWithAlias, help="""A host scan endpoint-protection-result command group""")
 @cli_util.help_option_group
 def host_scan_result_endpoint_protection_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.host_scan_target_override_group.command_name', 'target'), cls=CommandGroupWithAlias, help="""A host scan target command group""")
+@click.command(cli_util.override('vulnerability_scanning.host_group.command_name', 'target'), cls=CommandGroupWithAlias, help="""A host scan target command group""")
 @cli_util.help_option_group
 def host_scan_target_override_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.host_scan_recipe_override_group.command_name', 'recipe'), cls=CommandGroupWithAlias, help="""A host scan recipe command group""")
+@click.command(cli_util.override('vulnerability_scanning.host_group.command_name', 'recipe'), cls=CommandGroupWithAlias, help="""A host scan recipe command group""")
 @cli_util.help_option_group
 def host_scan_recipe_override_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.host_vulnerability_override_group.command_name', 'vulnerability'), cls=CommandGroupWithAlias, help="""A host vulnerability command group""")
+@click.command(cli_util.override('vulnerability_scanning.host_group.command_name', 'vulnerability'), cls=CommandGroupWithAlias, help="""A host vulnerability command group""")
 @cli_util.help_option_group
 def host_vulnerability_override_group():
     pass
@@ -216,19 +216,19 @@ def container_scan_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.container_scan_result_override_group.command_name', 'result'), cls=CommandGroupWithAlias, help="""A container scan result command group""")
+@click.command(cli_util.override('vulnerability_scanning.conatiner_scan_result_group.command_name', 'result'), cls=CommandGroupWithAlias, help="""A container scan result command group""")
 @cli_util.help_option_group
 def container_scan_result_override_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.container_scan_target_override_group.command_name', 'target'), cls=CommandGroupWithAlias, help="""A container scan target command group""")
+@click.command(cli_util.override('vulnerability_scanning.container_scan_target_group.command_name', 'target'), cls=CommandGroupWithAlias, help="""A container scan target command group""")
 @cli_util.help_option_group
 def container_scan_target_override_group():
     pass
 
 
-@click.command(cli_util.override('vulnerability_scanning.container_scan_recipe_override_group.command_name', 'recipe'), cls=CommandGroupWithAlias, help="""A container scan recipe command group""")
+@click.command(cli_util.override('vulnerability_scanning.container_scan_recipe_group.command_name', 'recipe'), cls=CommandGroupWithAlias, help="""A container scan recipe command group""")
 @cli_util.help_option_group
 def container_scan_recipe_override_group():
     pass
@@ -283,3 +283,17 @@ container_scan_result_override_group.add_command(vulnerabilityscanning_cli.get_c
 container_scan_result_override_group.add_command(vulnerabilityscanning_cli.delete_container_scan_result)
 container_scan_result_override_group.add_command(vulnerabilityscanning_cli.list_container_scan_results)
 container_scan_result_override_group.add_command(vulnerabilityscanning_cli.change_container_scan_result_compartment)
+
+
+# oci vulnerability-scanning host-scan-target-error-summary-collection list-host-scan-target-errors -> oci vulnerability-scanning host scan target
+vulnerabilityscanning_cli.host_scan_target_error_summary_collection_group.commands.pop(vulnerabilityscanning_cli.list_host_scan_target_errors.name)
+host_scan_target_override_group.add_command(vulnerabilityscanning_cli.list_host_scan_target_errors)
+
+
+# Remove host-scan-target-error-summary-collection from oci vulnerability-scanning
+vulnerabilityscanning_cli.vulnerability_scanning_root_group.commands.pop(vulnerabilityscanning_cli.host_scan_target_error_summary_collection_group.name)
+
+
+# rename: oci vulnerability-scanning host scan target list-host-scan-target-errors
+# to oci vulnerability-scanning host scan target list-error
+cli_util.rename_command(vulnerabilityscanning_cli, host_scan_target_override_group, vulnerabilityscanning_cli.list_host_scan_target_errors, "list-error")
