@@ -207,8 +207,43 @@ IGNORED_COMMANDS = [
     ['rover', 'device', 'diagnostics', 'bundle', 'get'],
     ['rover', 'device', 'diagnostics', 'bundle', 'list'],
     ['rover', 'device', 'diagnostics', 'bundle', 'view-summary'],
-    ['rover', 'device', 'system-upgrade', 'import-bundle']
-
+    ['rover', 'device', 'system-upgrade', 'import-bundle'],
+    ['database-management', 'tablespace', 'drop-with-pwd'],
+    ['database-management', 'tablespace', 'drop-with-secret'],
+    ['database-management', 'tablespace', 'remove-datafile-with-pwd'],
+    ['database-management', 'tablespace', 'remove-datafile-with-secret'],
+    ['database-management', 'managed-database', 'change-plan-retention-with-password'],
+    ['database-management', 'managed-database', 'change-plan-retention-with-secret'],
+    ['database-management', 'managed-database', 'change-space-budget-with-password'],
+    ['database-management', 'managed-database', 'change-space-budget-with-secret'],
+    ['database-management', 'managed-database', 'change-spb-attr-with-password'],
+    ['database-management', 'managed-database', 'change-spb-attr-with-secret'],
+    ['database-management', 'managed-database', 'cfg-auto-capture-filters-with-password'],
+    ['database-management', 'managed-database', 'cfg-auto-capture-filters-with-secret'],
+    ['database-management', 'managed-database', 'cfg-auto-spm-evolve-task-with-password'],
+    ['database-management', 'managed-database', 'cfg-auto-spm-evolve-task-with-secret'],
+    ['database-management', 'managed-database', 'disable-auto-plan-capture-with-password'],
+    ['database-management', 'managed-database', 'disable-auto-plan-capture-with-secret'],
+    ['database-management', 'managed-database', 'disable-auto-spm-evolve-task-with-password'],
+    ['database-management', 'managed-database', 'disable-auto-spm-evolve-task-with-secret'],
+    ['database-management', 'managed-database', 'disable-hf-auto-spm-evolve-task-with-password'],
+    ['database-management', 'managed-database', 'disable-hf-auto-spm-evolve-task-with-secret'],
+    ['database-management', 'managed-database', 'disable-spb-usage-with-password'],
+    ['database-management', 'managed-database', 'disable-spb-usage-with-secret'],
+    ['database-management', 'managed-database', 'drop-sql-plan-baselines-with-password'],
+    ['database-management', 'managed-database', 'drop-sql-plan-baselines-with-secret'],
+    ['database-management', 'managed-database', 'enable-auto-plan-capture-with-password'],
+    ['database-management', 'managed-database', 'enable-auto-plan-capture-with-secret'],
+    ['database-management', 'managed-database', 'enable-auto-spm-evolve-task-with-password'],
+    ['database-management', 'managed-database', 'enable-auto-spm-evolve-task-with-secret'],
+    ['database-management', 'managed-database', 'enable-hf-auto-spm-evolve-task-with-password'],
+    ['database-management', 'managed-database', 'enable-hf-auto-spm-evolve-task-with-secret'],
+    ['database-management', 'managed-database', 'enable-spb-usage-with-password'],
+    ['database-management', 'managed-database', 'enable-spb-usage-with-secret'],
+    ['database-management', 'managed-database', 'load-spb-from-awr-with-password'],
+    ['database-management', 'managed-database', 'load-spb-from-awr-with-secret'],
+    ['database-management', 'managed-database', 'load-spb-from-cc-with-password'],
+    ['database-management', 'managed-database', 'load-spb-from-cc-with-secret'],
 ]
 
 IGNORED_COMMANDS_DOCS = [
