@@ -19,9 +19,12 @@ OCI_CLI_AUTH_RESOURCE_PRINCIPAL = 'resource_principal'
 OCI_CLI_AUTH_INSTANCE_OBO_USER = 'instance_obo_user'
 OCI_CLI_AUTH_API_KEY = 'api_key'
 OCI_CLI_AUTH_SESSION_TOKEN = 'security_token'
+OCI_CLI_AUTH_OKE_WORKLOAD_IDENTITY = 'oke_workload_identity'
 OCI_CLI_UPST_TOKEN_MAX_TTL = '60'
 OCI_CLI_UPST_TOKEN_MIN_TTL = '5'
 
+OCI_KUBERNETES_SERVICE_ACCOUNT_TOKEN_PATH_ENV_VAR = 'OCI_KUBERNETES_SERVICE_ACCOUNT_TOKEN_PATH'
+OCI_KUBERNETES_SERVICE_ACCOUNT_TOKEN_STRING_ENV_VAR = 'OCI_KUBERNETES_SERVICE_ACCOUNT_TOKEN_STRING'
 OCI_CLI_REGION_ENV_VAR = 'OCI_CLI_REGION'
 OCI_CLI_USER_ENV_VAR = 'OCI_CLI_USER'
 OCI_CLI_FINGERPRINT_ENV_VAR = 'OCI_CLI_FINGERPRINT'
@@ -82,3 +85,5 @@ INTERACTIVE_CLI_SUGGESTION_MESSAGE = 'For OCI CLI commands and parameters sugges
                                      'other useful features, try the Interactive mode by typing `oci -i`.'
 
 NO_SUCH_COMMAND_ERROR_STRING = "{}\n\nError: No such command {}"
+SSE_RESPONSE_HEADER_VALUE = 'text/event-stream'
+READ_TIMEOUT_SSE = 60
