@@ -12,11 +12,15 @@ class CliCaseInsensitiveChoice(click.Choice):
     # This is: https://github.com/pallets/click/blob/b471d346e93b818d7c8a87d8cee9e0705435ac19/click/types.py#L145 but instead of relying
     # on the presence of a token_normalize_func, we always do a case insensitive match
     def convert(self, value, param, ctx):
-        if value in self.choices:
-            return value
+        if type(value) == list:
+            if set(map(str.lower, value)).issubset(set(map(str.lower, self.choices))):
+                return value
+        else:
+            if value in self.choices:
+                return value
 
-        for choice in self.choices:
-            if value.lower() == choice.lower():
-                return choice
+            for choice in self.choices:
+                if value.lower() == choice.lower():
+                    return choice
 
         self.fail('invalid choice: {}. (choose from {})'.format(value, ', '.join(self.choices)), param, ctx)
